SOAP-WSSE
=========

Simply library to sign and verify SOAP XML requests using the
BinarySecurityToken specification.

Improvements welcome :-)



Continuous integration status:

.. image:: https://travis-ci.org/mvantellingen/py-soap-wsse.svg?branch=master
    :target: https://travis-ci.org/mvantellingen/py-soap-wsse

.. image:: https://coveralls.io/repos/mvantellingen/py-soap-wsse/badge.svg
    :alt: Coverage
    :target: https://coveralls.io/r/mvantellingen/py-soap-wsse


References
----------
 - http://vsza.hu/thesis-beta.pdf
 - https://github.com/dnet/SudsSigner
